@@ -4,9 +4,8 @@ from pathlib import Path
 
 from enum import Enum
 from datetime import timedelta
-from airflow.kubernetes.volume import Volume
-from airflow.kubernetes.volume_mount import VolumeMount
 from airflow.contrib.operators import kubernetes_pod_operator
+from kubernetes.client.models import V1Volume, V1VolumeMount
 from knada_composer_wrappers.init_containers import create_read_bucket_init_container
 
 
@@ -35,12 +34,12 @@ def create_dbt_pod_operator(
         env_vars={"REQUESTS_CA_BUNDLE": "/etc/ssl/certs/ca-certificates.crt"},
         namespace=namespace,
         volume_mounts=[
-            VolumeMount(
+            V1VolumeMount(
                 name="data", mount_path="data", sub_path=None, read_only=False
             )
         ],
         startup_timeout_seconds=startup_timeout_seconds,
-        volumes=[Volume(name="data", configs={})],
+        volumes=[V1Volume(name="data")],
         image=os.getenv("KNADA_DBT_IMAGE", "navikt/knada-dbt:4"),
         retries=retries,
         retry_delay=retry_delay,
@@ -74,11 +73,11 @@ def create_python_pod_operator(
         env_vars=envs,
         namespace=namespace,
         volume_mounts=[
-            VolumeMount(
+            V1VolumeMount(
                 name="data", mount_path="data", sub_path=None, read_only=False
             )
         ],
-        volumes=[Volume(name="data", configs={})],
+        volumes=[V1Volume(name="data")],
         image=os.getenv("KNADA_PYTHON_IMAGE", "navikt/dataprodukt-poc:v6"),
         retries=retries,
         retry_delay=retry_delay,
@@ -119,11 +118,11 @@ def create_nb_pod_operator(
         env_vars=env_vars,
         namespace=namespace,
         volume_mounts=[
-            VolumeMount(
+            V1VolumeMount(
                 name="data", mount_path="/workspace", sub_path=None, read_only=False
             )
         ],
-        volumes=[Volume(name="data", configs={})],
+        volumes=[V1Volume(name="data")],
         image=os.getenv("KNADA_NOTEBOOK_OP_IMAGE", "navikt/knada-airflow-nb:2021-09-02-6e78659"),
         retries=retries,
         retry_delay=retry_delay,
